# FEasyTools: Some useful components
- dprov: Data provider as time functions
- argchk: Argument parser with type checking
- table: Table helper for the CSV, SDT & SDT.GZ format, and their reader and writer.
- pq: Heap, priority queue & buffered priority queue
- rangelist: An xml reader for a time range list
